==> ui-0.2.43.tgz: package/lib/cjs/Toggle/Toggle.js <==
"use strict";

var _WeakMap = require("@babel/runtime-corejs3/core-js-stable/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _indexOf = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/index-of"));
var _getOwnPropertySymbols = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-symbols"));
var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));
var _bind = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/bind"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react = require("react");
var _classnames = _interopRequireDefault(require("classnames"));
var Styled = _interopRequireWildcard(require("./Toggle.styled"));
function _getRequireWildcardCache(nodeInterop) { if (typeof _WeakMap !== "function") return null; var cacheBabelInterop = new _WeakMap(); var cacheNodeInterop = new _WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? _Object$getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { _Object$defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && (0, _indexOf.default)(e).call(e, p) < 0) t[p] = s[p];
  if (s != null && typeof _getOwnPropertySymbols.default === "function") for (var i = 0, p = (0, _getOwnPropertySymbols.default)(s); i < p.length; i++) {
    if ((0, _indexOf.default)(e).call(e, p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};

// import { useEffect, useRef, useState } from 'react';
// import classNames from 'classnames';
// import * as Styled from './Toggle.styled';
// import { PointerCoordinates, ToggleProps } from './Toggle.types';
//
// function usePrevious<T>(value: T): T {
//   const ref = useRef<T>();
//   useEffect(() => {
//     ref.current = value;
//   });
//   return ref.current;
// }
//
// function pointerCoord(ev: any): PointerCoordinates {
//   if (!ev) return { x: 0, y: 0 };
//
//   const changedTouches = ev.changedTouches;
//   if (changedTouches && changedTouches.length > 0) {
//     const touch = changedTouches[0];
//     return { x: touch.clientX, y: touch.clientY };
//   }
//
//   const pageX = ev.pageX;
//   if (pageX !== undefined) return { x: pageX, y: ev.pageY };
// }
//
// const Toggle = ({
//   checked = false,
//   defaultChecked,
//   disabled,
//   onFocus,
//   onBlur,
//   ...rest
// }: ToggleProps) => {
//   let prevChecked = usePrevious(!!(checked || defaultChecked));
//   const inputRef = useRef<HTMLInputElement>(null);
//
//   const [localChecked, setLocalChecked] = useState(!!(checked || defaultChecked));
//   const [hasFocus, setFocus] = useState(false);
//   const [moved, setMoved] = useState(false);
//   const [startX, setStartX] = useState<number | null>(null);
//   const [activated, setActivated] = useState(false);
//
//   useEffect(() => {
//     if (prevChecked !== checked) setLocalChecked(!!checked);
//   }, [prevChecked, checked]);
//
//   const handleClick = (event) => {
//     if (disabled) return;
//
//     event.preventDefault();
//
//     const checkbox = inputRef.current;
//     if (event.target !== checkbox && !moved) {
//       prevChecked = checkbox.checked;
//       checkbox.focus();
//       checkbox.click();
//       return;
//     }
//
//     setLocalChecked(checked ? checked : checkbox.checked);
//   };
//
//   const handleTouchStart = (event) => {
//     if (disabled) return;
//
//     setStartX(pointerCoord(event).x);
//     setActivated(true);
//   };
//
//   const handleTouchMove = (event) => {
//     if (!activated) return;
//     setMoved(true);
//
//     if (!startX) return;
//
//     const currentX = pointerCoord(event).x;
//     if (localChecked && currentX + 15 < startX) {
//       setLocalChecked(false);
//       setStartX(currentX);
//       setActivated(true);
//     } else if (currentX - 15 > startX) {
//       setLocalChecked(true);
//       setStartX(currentX);
//       setActivated(currentX < startX + 5);
//     }
//   };
//
//   const handleTouchEnd = (event) => {
//     if (!moved) return;
//     const checkbox = inputRef.current;
//     event.preventDefault();
//
//     if (startX) return;
//
//     const endX = pointerCoord(event).x;
//     if (prevChecked && startX + 4 > endX && prevChecked !== localChecked) {
//       setLocalChecked(false);
//       prevChecked = localChecked;
//       checkbox.click();
//     } else if (startX - 4 < endX && prevChecked !== localChecked) {
//       setLocalChecked(true);
//       prevChecked = localChecked;
//       checkbox.click();
//     }
//
//     setActivated(false);
//     setStartX(null);
//     setMoved(false);
//   };
//
//   const handleFocus = (event) => {
//     if (onFocus) {
//       onFocus(event);
//     }
//     setFocus(true);
//   };
//
//   const handleBlur = (event) => {
//     if (onBlur) {
//       onBlur(event);
//     }
//
//     setFocus(false);
//   };
//
//   const { className, ...inputProps } = rest;
//   const classes = classNames(
//     'nu-toggle',
//     {
//       'nu-toggle--checked': localChecked,
//       'nu-toggle--focus': hasFocus,
//       'nu-toggle--disabled': disabled,
//     },
//     className,
//   );
//
//   return (
//     <Styled.ToggleWrapper
//       className={classes}
//       onClick={handleClick}
//       // $checked={localChecked}
//       // $focus={hasFocus}
//       // $disabled={disabled}
//       // onTouchStart={handleTouchStart}
//       // onTouchMove={handleTouchMove}
//       // onTouchEnd={handleTouchEnd}
//     >
//       <Styled.ToggleArea className="nu-toggle-track">
//         <Styled.ToggleCheck className="nu-toggle-track-check">
//           {/* 체크 시 아이콘 영역 */}
//         </Styled.ToggleCheck>
//         <Styled.ToggleUncheck className="nu-toggle-track-uncheck">
//           {/* 미체크 시 아이콘 영역 */}
//         </Styled.ToggleUncheck>
//       </Styled.ToggleArea>
//       <Styled.ToggleCircle className="nu-toggle-thumb" />
//
//       <Styled.ToggleInput
//         {...inputProps}
//         ref={inputRef}
//         // onFocus={handleFocus}
//         // onBlur={handleBlur}
//         checked={localChecked}
//         type="checkbox"
//       />
//     </Styled.ToggleWrapper>
//   );
// };
//
// export default Toggle;
const Check = () => (0, _jsxRuntime.jsx)("svg", (0, _assign.default)({
  width: "14",
  height: "11",
  viewBox: "0 0 14 11"
}, {
  children: (0, _jsxRuntime.jsx)("path", {
    d: "M11.264 0L5.26 6.004 2.103 2.847 0 4.95l5.26 5.26 8.108-8.107L11.264 0",
    fill: "#fff",
    fillRule: "evenodd"
  })
}));
const X = () => (0, _jsxRuntime.jsx)("svg", (0, _assign.default)({
  width: "10",
  height: "10",
  viewBox: "0 0 10 10"
}, {
  children: (0, _jsxRuntime.jsx)("path", {
    d: "M9.9 2.12L7.78 0 4.95 2.828 2.12 0 0 2.12l2.83 2.83L0 7.776 2.123 9.9 4.95 7.07 7.78 9.9 9.9 7.776 7.072 4.95 9.9 2.12",
    fill: "#fff",
    fillRule: "evenodd"
  })
}));
function pointerCoord(ev) {
  if (!ev) return {
    x: 0,
    y: 0
  };
  const changedTouches = ev.changedTouches;
  if (changedTouches && changedTouches.length > 0) {
    const touch = changedTouches[0];
    return {
      x: touch.clientX,
      y: touch.clientY
    };
  }
  const pageX = ev.pageX;
  if (pageX !== undefined) return {
    x: pageX,
    y: ev.pageY
  };
}
class Toggle extends _react.Component {
  constructor(props) {
    var _context, _context2, _context3, _context4, _context5, _context6;
    super(props);
    this.handleClick = (0, _bind.default)(_context = this.handleClick).call(_context, this);
    this.handleTouchStart = (0, _bind.default)(_context2 = this.handleTouchStart).call(_context2, this);
    this.handleTouchMove = (0, _bind.default)(_context3 = this.handleTouchMove).call(_context3, this);
    this.handleTouchEnd = (0, _bind.default)(_context4 = this.handleTouchEnd).call(_context4, this);
    this.handleFocus = (0, _bind.default)(_context5 = this.handleFocus).call(_context5, this);
    this.handleBlur = (0, _bind.default)(_context6 = this.handleBlur).call(_context6, this);
    this.previouslyChecked = !!(props.checked || props.defaultChecked);
    this.state = {
      checked: !!(props.checked || props.defaultChecked),
      hasFocus: false
    };
  }
  componentDidUpdate(prevProps) {
    if (prevProps.checked !== this.props.checked) {
      this.setState({
        checked: !!this.props.checked
      });
    }
  }
  handleClick(event) {
    if (this.props.disabled) {
      return;
    }
    const checkbox = this.input;
    if (event.target !== checkbox && !this.moved) {
      this.previouslyChecked = checkbox.checked;
      event.preventDefault();
      checkbox.focus();
      checkbox.click();
      return;
    }
    const checked = this.props.hasOwnProperty('checked') ? this.props.checked : checkbox.checked;
    this.setState({
      checked
    });
  }
  handleTouchStart(event) {
    if (this.props.disabled) {
      return;
    }
    this.startX = pointerCoord(event).x;
    this.activated = true;
  }
  handleTouchMove(event) {
    if (!this.activated) return;
    this.moved = true;
    if (this.startX) {
      const currentX = pointerCoord(event).x;
      if (this.state.checked && currentX + 15 < this.startX) {
        this.setState({
          checked: false
        });
        this.startX = currentX;
        this.activated = true;
      } else if (currentX - 15 > this.startX) {
        this.setState({
          checked: true
        });
        this.startX = currentX;
        this.activated = currentX < this.startX + 5;
      }
    }
  }
  handleTouchEnd(event) {
    if (!this.moved) return;
    const checkbox = this.input;
    event.preventDefault();
    if (this.startX) {
      const endX = pointerCoord(event).x;
      if (this.previouslyChecked === true && this.startX + 4 > endX) {
        if (this.previouslyChecked !== this.state.checked) {
          this.setState({
            checked: false
          });
          this.previouslyChecked = this.state.checked;
          checkbox.click();
        }
      } else if (this.startX - 4 < endX) {
        if (this.previouslyChecked !== this.state.checked) {
          this.setState({
            checked: true
          });
          this.previouslyChecked = this.state.checked;
          checkbox.click();
        }
      }
      this.activated = false;
      this.startX = null;
      this.moved = false;
    }
  }
  handleFocus(event) {
    const {
      onFocus
    } = this.props;
    if (onFocus) {
      onFocus(event);
    }
    this.setState({
      hasFocus: true
    });
  }
  handleBlur(event) {
    const {
      onBlur
    } = this.props;
    if (onBlur) {
      onBlur(event);
    }
    this.setState({
      hasFocus: false
    });
  }
  getIcon(type) {
    const {
      icons
    } = this.props;
    if (!icons) {
      return null;
    }
    return icons[type] === undefined ? Toggle.defaultProps.icons[type] : icons[type];
  }
  render() {
    const _a = this.props,
      {
        className,
        icons: _icons
      } = _a,
      inputProps = __rest(_a, ["className", "icons"]);
    const classes = (0, _classnames.default)('nu-toggle', {
      'nu-toggle--checked': this.state.checked,
      'nu-toggle--focus': this.state.hasFocus,
      'nu-toggle--disabled': this.props.disabled
    }, className);
    return (0, _jsxRuntime.jsxs)(Styled.ToggleWrapper, (0, _assign.default)({
      className: classes,
      onClick: this.handleClick,
      onTouchStart: this.handleTouchStart,
      onTouchMove: this.handleTouchMove,
      onTouchEnd: this.handleTouchEnd
    }, {
      children: [(0, _jsxRuntime.jsxs)(Styled.ToggleArea, (0, _assign.default)({
        className: "nu-toggle-track"
      }, {
        children: [(0, _jsxRuntime.jsx)(Styled.ToggleCheck, {
          className: "nu-toggle-track-check"
        }), (0, _jsxRuntime.jsx)(Styled.ToggleUncheck, {
          className: "nu-toggle-track-uncheck"
        })]
      })), (0, _jsxRuntime.jsx)(Styled.ToggleCircle, {
        className: "nu-toggle-thumb"
      }), (0, _jsxRuntime.jsx)(Styled.ToggleInput, (0, _assign.default)({}, inputProps, {
        ref: ref => {
          this.input = ref;
        },
        onFocus: this.handleFocus,
        onBlur: this.handleBlur,
        className: "nu-toggle-screenreader-only",
        type: "checkbox"
      }))]
    }));
  }
}
exports.default = Toggle;
Toggle.displayName = 'Toggle';
Toggle.defaultProps = {
  icons: {
    checked: (0, _jsxRuntime.jsx)(Check, {}),
    unchecked: (0, _jsxRuntime.jsx)(X, {})
  }
};

==> ui-0.2.52.tgz: package/lib/cjs/Toggle/Toggle.js <==
"use strict";

var _WeakMap = require("@babel/runtime-corejs3/core-js-stable/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _indexOf = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/index-of"));
var _getOwnPropertySymbols = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-symbols"));
var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));
var _bind = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/bind"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react = require("react");
var _classnames = _interopRequireDefault(require("classnames"));
var Styled = _interopRequireWildcard(require("./Toggle.styled"));
function _getRequireWildcardCache(e) { if ("function" != typeof _WeakMap) return null; var r = new _WeakMap(), t = new _WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? _Object$getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? _Object$defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && (0, _indexOf.default)(e).call(e, p) < 0) t[p] = s[p];
  if (s != null && typeof _getOwnPropertySymbols.default === "function") for (var i = 0, p = (0, _getOwnPropertySymbols.default)(s); i < p.length; i++) {
    if ((0, _indexOf.default)(e).call(e, p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};

// import { useEffect, useRef, useState } from 'react';
// import classNames from 'classnames';
// import * as Styled from './Toggle.styled';
// import { PointerCoordinates, ToggleProps } from './Toggle.types';
//
// function usePrevious<T>(value: T): T {
//   const ref = useRef<T>();
//   useEffect(() => {
//     ref.current = value;
//   });
//   return ref.current;
// }
//
// function pointerCoord(ev: any): PointerCoordinates {
//   if (!ev) return { x: 0, y: 0 };
//
//   const changedTouches = ev.changedTouches;
//   if (changedTouches && changedTouches.length > 0) {
//     const touch = changedTouches[0];
//     return { x: touch.clientX, y: touch.clientY };
//   }
//
//   const pageX = ev.pageX;
//   if (pageX !== undefined) return { x: pageX, y: ev.pageY };
// }
//
// const Toggle = ({
//   checked = false,
//   defaultChecked,
//   disabled,
//   onFocus,
//   onBlur,
//   ...rest
// }: ToggleProps) => {
//   let prevChecked = usePrevious(!!(checked || defaultChecked));
//   const inputRef = useRef<HTMLInputElement>(null);
//
//   const [localChecked, setLocalChecked] = useState(!!(checked || defaultChecked));
//   const [hasFocus, setFocus] = useState(false);
//   const [moved, setMoved] = useState(false);
//   const [startX, setStartX] = useState<number | null>(null);
//   const [activated, setActivated] = useState(false);
//
//   useEffect(() => {
//     if (prevChecked !== checked) setLocalChecked(!!checked);
//   }, [prevChecked, checked]);
//
//   const handleClick = (event) => {
//     if (disabled) return;
//
//     event.preventDefault();
//
//     const checkbox = inputRef.current;
//     if (event.target !== checkbox && !moved) {
//       prevChecked = checkbox.checked;
//       checkbox.focus();
//       checkbox.click();
//       return;
//     }
//
//     setLocalChecked(checked ? checked : checkbox.checked);
//   };
//
//   const handleTouchStart = (event) => {
//     if (disabled) return;
//
//     setStartX(pointerCoord(event).x);
//     setActivated(true);
//   };
//
//   const handleTouchMove = (event) => {
//     if (!activated) return;
//     setMoved(true);
//
//     if (!startX) return;
//
//     const currentX = pointerCoord(event).x;
//     if (localChecked && currentX + 15 < startX) {
//       setLocalChecked(false);
//       setStartX(currentX);
//       setActivated(true);
//     } else if (currentX - 15 > startX) {
//       setLocalChecked(true);
//       setStartX(currentX);
//       setActivated(currentX < startX + 5);
//     }
//   };
//
//   const handleTouchEnd = (event) => {
//     if (!moved) return;
//     const checkbox = inputRef.current;
//     event.preventDefault();
//
//     if (startX) return;
//
//     const endX = pointerCoord(event).x;
//     if (prevChecked && startX + 4 > endX && prevChecked !== localChecked) {
//       setLocalChecked(false);
//       prevChecked = localChecked;
//       checkbox.click();
//     } else if (startX - 4 < endX && prevChecked !== localChecked) {
//       setLocalChecked(true);
//       prevChecked = localChecked;
//       checkbox.click();
//     }
//
//     setActivated(false);
//     setStartX(null);
//     setMoved(false);
//   };
//
//   const handleFocus = (event) => {
//     if (onFocus) {
//       onFocus(event);
//     }
//     setFocus(true);
//   };
//
//   const handleBlur = (event) => {
//     if (onBlur) {
//       onBlur(event);
//     }
//
//     setFocus(false);
//   };
//
//   const { className, ...inputProps } = rest;
//   const classes = classNames(
//     'nu-toggle',
//     {
//       'nu-toggle--checked': localChecked,
//       'nu-toggle--focus': hasFocus,
//       'nu-toggle--disabled': disabled,
//     },
//     className,
//   );
//
//   return (
//     <Styled.ToggleWrapper
//       className={classes}
//       onClick={handleClick}
//       // $checked={localChecked}
//       // $focus={hasFocus}
//       // $disabled={disabled}
//       // onTouchStart={handleTouchStart}
//       // onTouchMove={handleTouchMove}
//       // onTouchEnd={handleTouchEnd}
//     >
//       <Styled.ToggleArea className="nu-toggle-track">
//         <Styled.ToggleCheck className="nu-toggle-track-check">
//           {/* 체크 시 아이콘 영역 */}
//         </Styled.ToggleCheck>
//         <Styled.ToggleUncheck className="nu-toggle-track-uncheck">
//           {/* 미체크 시 아이콘 영역 */}
//         </Styled.ToggleUncheck>
//       </Styled.ToggleArea>
//       <Styled.ToggleCircle className="nu-toggle-thumb" />
//
//       <Styled.ToggleInput
//         {...inputProps}
//         ref={inputRef}
//         // onFocus={handleFocus}
//         // onBlur={handleBlur}
//         checked={localChecked}
//         type="checkbox"
//       />
//     </Styled.ToggleWrapper>
//   );
// };
//
// export default Toggle;
const Check = () => (0, _jsxRuntime.jsx)("svg", (0, _assign.default)({
  width: "14",
  height: "11",
  viewBox: "0 0 14 11"
}, {
  children: (0, _jsxRuntime.jsx)("path", {
    d: "M11.264 0L5.26 6.004 2.103 2.847 0 4.95l5.26 5.26 8.108-8.107L11.264 0",
    fill: "#fff",
    fillRule: "evenodd"
  })
}));
const X = () => (0, _jsxRuntime.jsx)("svg", (0, _assign.default)({
  width: "10",
  height: "10",
  viewBox: "0 0 10 10"
}, {
  children: (0, _jsxRuntime.jsx)("path", {
    d: "M9.9 2.12L7.78 0 4.95 2.828 2.12 0 0 2.12l2.83 2.83L0 7.776 2.123 9.9 4.95 7.07 7.78 9.9 9.9 7.776 7.072 4.95 9.9 2.12",
    fill: "#fff",
    fillRule: "evenodd"
  })
}));
function pointerCoord(ev) {
  if (!ev) return {
    x: 0,
    y: 0
  };
  const changedTouches = ev.changedTouches;
  if (changedTouches && changedTouches.length > 0) {
    const touch = changedTouches[0];
    return {
      x: touch.clientX,
      y: touch.clientY
    };
  }
  const pageX = ev.pageX;
  if (pageX !== undefined) return {
    x: pageX,
    y: ev.pageY
  };
}
class Toggle extends _react.Component {
  constructor(props) {
    var _context, _context2, _context3, _context4, _context5, _context6;
    super(props);
    this.handleClick = (0, _bind.default)(_context = this.handleClick).call(_context, this);
    this.handleTouchStart = (0, _bind.default)(_context2 = this.handleTouchStart).call(_context2, this);
    this.handleTouchMove = (0, _bind.default)(_context3 = this.handleTouchMove).call(_context3, this);
    this.handleTouchEnd = (0, _bind.default)(_context4 = this.handleTouchEnd).call(_context4, this);
    this.handleFocus = (0, _bind.default)(_context5 = this.handleFocus).call(_context5, this);
    this.handleBlur = (0, _bind.default)(_context6 = this.handleBlur).call(_context6, this);
    this.previouslyChecked = !!(props.checked || props.defaultChecked);
    this.state = {
      checked: !!(props.checked || props.defaultChecked),
      hasFocus: false
    };
  }
  componentDidUpdate(prevProps) {
    if (prevProps.checked !== this.props.checked) {
      this.setState({
        checked: !!this.props.checked
      });
    }
  }
  handleClick(event) {
    if (this.props.disabled) {
      return;
    }
    const checkbox = this.input;
    if (event.target !== checkbox && !this.moved) {
      this.previouslyChecked = checkbox.checked;
      event.preventDefault();
      checkbox.focus();
      checkbox.click();
      return;
    }
    const checked = this.props.hasOwnProperty('checked') ? this.props.checked : checkbox.checked;
    this.setState({
      checked
    });
  }
  handleTouchStart(event) {
    if (this.props.disabled) {
      return;
    }
    this.startX = pointerCoord(event).x;
    this.activated = true;
  }
  handleTouchMove(event) {
    if (!this.activated) return;
    this.moved = true;
    if (this.startX) {
      const currentX = pointerCoord(event).x;
      if (this.state.checked && currentX + 15 < this.startX) {
        this.setState({
          checked: false
        });
        this.startX = currentX;
        this.activated = true;
      } else if (currentX - 15 > this.startX) {
        this.setState({
          checked: true
        });
        this.startX = currentX;
        this.activated = currentX < this.startX + 5;
      }
    }
  }
  handleTouchEnd(event) {
    if (!this.moved) return;
    const checkbox = this.input;
    event.preventDefault();
    if (this.startX) {
      const endX = pointerCoord(event).x;
      if (this.previouslyChecked === true && this.startX + 4 > endX) {
        if (this.previouslyChecked !== this.state.checked) {
          this.setState({
            checked: false
          });
          this.previouslyChecked = this.state.checked;
          checkbox.click();
        }
      } else if (this.startX - 4 < endX) {
        if (this.previouslyChecked !== this.state.checked) {
          this.setState({
            checked: true
          });
          this.previouslyChecked = this.state.checked;
          checkbox.click();
        }
      }
      this.activated = false;
      this.startX = null;
      this.moved = false;
    }
  }
  handleFocus(event) {
    const {
      onFocus
    } = this.props;
    if (onFocus) {
      onFocus(event);
    }
    this.setState({
      hasFocus: true
    });
  }
  handleBlur(event) {
    const {
      onBlur
    } = this.props;
    if (onBlur) {
      onBlur(event);
    }
    this.setState({
      hasFocus: false
    });
  }
  getIcon(type) {
    const {
      icons
    } = this.props;
    if (!icons) {
      return null;
    }
    return icons[type] === undefined ? Toggle.defaultProps.icons[type] : icons[type];
  }
  render() {
    const _a = this.props,
      {
        className,
        icons: _icons
      } = _a,
      inputProps = __rest(_a, ["className", "icons"]);
    const classes = (0, _classnames.default)('nu-toggle', {
      'nu-toggle--checked': this.state.checked,
      'nu-toggle--focus': this.state.hasFocus,
      'nu-toggle--disabled': this.props.disabled
    }, className);
    return (0, _jsxRuntime.jsxs)(Styled.ToggleWrapper, (0, _assign.default)({
      className: classes,
      onClick: this.handleClick,
      onTouchStart: this.handleTouchStart,
      onTouchMove: this.handleTouchMove,
      onTouchEnd: this.handleTouchEnd
    }, {
      children: [(0, _jsxRuntime.jsxs)(Styled.ToggleArea, (0, _assign.default)({
        className: "nu-toggle-track"
      }, {
        children: [(0, _jsxRuntime.jsx)(Styled.ToggleCheck, {
          className: "nu-toggle-track-check"
        }), (0, _jsxRuntime.jsx)(Styled.ToggleUncheck, {
          className: "nu-toggle-track-uncheck"
        })]
      })), (0, _jsxRuntime.jsx)(Styled.ToggleCircle, {
        className: "nu-toggle-thumb"
      }), (0, _jsxRuntime.jsx)(Styled.ToggleInput, (0, _assign.default)({}, inputProps, {
        ref: ref => {
          this.input = ref;
        },
        onFocus: this.handleFocus,
        onBlur: this.handleBlur,
        className: "nu-toggle-screenreader-only",
        type: "checkbox"
      }))]
    }));
  }
}
exports.default = Toggle;
Toggle.displayName = 'Toggle';
Toggle.defaultProps = {
  icons: {
    checked: (0, _jsxRuntime.jsx)(Check, {}),
    unchecked: (0, _jsxRuntime.jsx)(X, {})
  }
};
